==> owncloud-4.0.4.tgz: owncloud/apps/files/l10n/lb.php <==
<?php $TRANSLATIONS = array(
"There is no error, the file uploaded with success" => "Keen Feeler, Datei ass komplett ropgelueden ginn",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "Déi ropgelueden Datei ass méi grouss wei d'upload_max_filesize Eegenschaft an der php.ini",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "Déi ropgelueden Datei ass méi grouss wei d'MAX_FILE_SIZE Eegenschaft déi an der HTML form uginn ass",
"The uploaded file was only partially uploaded" => "Déi ropgelueden Datei ass nëmmen hallef ropgelueden ginn",
"No file was uploaded" => "Et ass keng Datei ropgelueden ginn",
"Missing a temporary folder" => "Et feelt en temporären Dossier",
"Failed to write to disk" => "Konnt net op den Disk schreiwen",
"Files" => "Dateien",
"Size" => "Gréisst",
"Modified" => "Geännert",
"File handling" => "Fichier handling",
"Maximum upload size" => "Maximum Upload Gréisst ",
"max. possible: " => "max. méiglech:",
"Needed for multi-file and folder downloads." => "Gett gebraucht fir multi-Fichier an Dossier Downloads.",
"Enable ZIP-download" => "ZIP-download erlaben",
"0 is unlimited" => "0 ass onlimitéiert",
"Maximum input size for ZIP files" => "Maximal Gréisst fir ZIP Fichieren",
"New" => "Nei",
"Text file" => "Text Fichier",
"Folder" => "Dossier",
"From url" => "From URL",
"Upload" => "Eroplueden",
"Cancel upload" => "Upload ofbriechen",
"Nothing in here. Upload something!" => "Hei ass näischt. Lued eppes rop!",
"Name" => "Numm",
"Share" => "Share",
"Download" => "Eroflueden",
"Delete" => "Läschen",
"Upload too large" => "Upload ze grouss",
"The files you are trying to upload exceed the maximum size for file uploads on this server." => "Déi Dateien déi Dir probéiert erop ze lueden sinn méi grouss wei déi Maximal Gréisst déi op dësem Server erlaabt ass.",
"Files are being scanned, please wait." => "Fichieren gi gescannt, war weg.",
"Current scanning" => "Momentane Scan"
);

==> owncloud-4.5.7.tgz: owncloud/apps/files/l10n/lb.php <==
<?php $TRANSLATIONS = array(
"There is no error, the file uploaded with success" => "Keen Feeler, Datei ass komplett ropgelueden ginn",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "Déi ropgelueden Datei ass méi grouss wei d'upload_max_filesize Eegenschaft an der php.ini",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "Déi ropgelueden Datei ass méi grouss wei d'MAX_FILE_SIZE Eegenschaft déi an der HTML form uginn ass",
"The uploaded file was only partially uploaded" => "Déi ropgelueden Datei ass nëmmen hallef ropgelueden ginn",
"No file was uploaded" => "Et ass keng Datei ropgelueden ginn",
"Missing a temporary folder" => "Et feelt en temporären Dossier",
"Failed to write to disk" => "Konnt net op den Disk schreiwen",
"Files" => "Dateien",
"Delete" => "Läschen",
"already exists" => "existéiert schonn",
"replace" => "ersetzen",
"cancel" => "ofbriechen",
"replaced" => "ersat",
"undo" => "réckgängeg man",
"with" => "mat",
"deleted" => "geläscht",
"generating ZIP-file, it may take some time." => "Et  gëtt eng ZIP-File generéiert, dëst ka bëssen daueren.",
"Unable to upload your file as it is a directory or has 0 bytes" => "Kann deng Datei net eroplueden well et en Dossier ass oder 0 byte grouss ass.",
"Upload Error" => "Fehler beim eroplueden",
"Upload cancelled." => "Upload ofgebrach.",
"File upload is in progress. Leaving the page now will cancel the upload." => "File Upload am gaang. Wann's de des Säit verléiss gëtt den Upload ofgebrach.",
"Invalid name, '/' is not allowed." => "Ongültege Numm, '/' net erlaabt.",
"Name" => "Numm",
"Size" => "Gréisst",
"Modified" => "Geännert",
"folder" => "Dossier",
"folders" => "Dossieren",
"file" => "Datei",
"files" => "Dateien",
"File handling" => "Fichier handling",
"Maximum upload size" => "Maximum Upload Gréisst ",
"max. possible: " => "max. méiglech:",
"Needed for multi-file and folder downloads." => "Gett gebraucht fir multi-Fichier an Dossier Downloads.",
"Enable ZIP-download" => "ZIP-download erlaben",
"0 is unlimited" => "0 ass onlimitéiert",
"Maximum input size for ZIP files" => "Maximal Gréisst fir ZIP Fichieren",
"New" => "Nei",
"Text file" => "Text Fichier",
"Folder" => "Dossier",
"From url" => "From URL",
"Upload" => "Eroplueden",
"Cancel upload" => "Upload ofbriechen",
"Nothing in here. Upload something!" => "Hei ass näischt. Lued eppes rop!",
"Share" => "Share",
"Download" => "Eroflueden",
"Upload too large" => "Upload ze grouss",
"The files you are trying to upload exceed the maximum size for file uploads on this server." => "Déi Dateien déi Dir probéiert erop ze lueden sinn méi grouss wei déi Maximal Gréisst déi op dësem Server erlaabt ass.",
"Files are being scanned, please wait." => "Fichieren gi gescannt, war weg.",
"Current scanning" => "Momentane Scan"
);
